@@ -31,6 +31,11 @@ class TaskAllocator(metaclass=abc.ABCMeta):
         task id"""
         raise NotImplementedError()
 
+    @abc.abstractmethod
+    def has_available_worker(self) -> bool:
+        """has available worker or not"""
+        raise NotImplementedError()
+
     @abc.abstractmethod
     def statistics(self) -> Dict:
         raise NotImplementedError()
