@@ -1,5 +1,4 @@
 import asyncio
-import enum
 import logging
 import time
 from typing import Dict, Optional, Tuple
@@ -13,14 +12,6 @@ from scaled.scheduler.worker_manager.allocators.queued import QueuedAllocator
 POLLING_TIME = 1
 
 
-class AllocatorType(enum.Enum):
-    OneToOne = "one_to_one"
-    Queued = "queued"
-
-    def __repr__(self):
-        return self.value
-
-
 class VanillaWorkerManager(WorkerManager, Looper):
     def __init__(self, per_worker_queue_size: int, timeout_seconds: int):
         self._timeout_seconds = timeout_seconds
@@ -53,7 +44,7 @@ class VanillaWorkerManager(WorkerManager, Looper):
     async def on_task_cancel(self, task_id: bytes):
         worker = self._allocator.get_assigned_worker(task_id)
         if worker is None:
-            logging.error(f"cannot find {task_id=} in task workers")
+            logging.error(f"cannot find task_id={task_id.hex()} in task workers")
             return
 
         await self._binder.send(worker, MessageType.TaskCancel, TaskCancel(task_id))
@@ -62,7 +53,8 @@ class VanillaWorkerManager(WorkerManager, Looper):
         worker = self._allocator.remove_task(task_result.task_id)
         if worker is None:
             logging.error(
-                f"received task_id={task_result.task_id} not known to any worker, might due to worker get disconnected"
+                f"received task_id={task_result.task_id.hex()} not known to any worker, might due to worker get "
+                f"disconnected"
             )
             return
 
@@ -80,15 +72,18 @@ class VanillaWorkerManager(WorkerManager, Looper):
     async def statistics(self) -> Dict:
         worker_to_task_numbers = self._allocator.statistics()
         return {
-            "free_slots": sum(worker["free"] for worker in worker_to_task_numbers.values()),
+            "scheduler_total_free": sum(worker["scheduler_free"] for worker in worker_to_task_numbers.values()),
+            "scheduler_total_running": sum(worker["scheduler_running"] for worker in worker_to_task_numbers.values()),
+            "worker_total_queued_tasks": sum(info.queued_tasks for _, (_, info) in self._worker_alive_since.items()),
             "workers": {
                 worker.decode(): {
-                    "cpu": round(info.cpu_usage, 2),
-                    "rss": info.rss_size,
+                    "worker_cpu": round(info.cpu_usage, 2),
+                    "worker_rss": info.rss_size,
+                    "worker_queued_tasks": info.queued_tasks,
                     **worker_to_task_numbers[worker],
                 }
                 for worker, (last, info) in self._worker_alive_since.items()
-            }
+            },
         }
 
     async def __routine(self):
