@@ -1,16 +1,27 @@
 import logging
 import multiprocessing
+import pickle
 import signal
 import time
 from typing import Callable, Dict, Optional
 
+import tblib.pickling_support
 import zmq
 import zmq.asyncio
 
+from scaled.io.config import DEFAULT_WORKER_PROCESSING_QUEUE_SIZE
 from scaled.io.sync_connector import SyncConnector
 from scaled.protocol.python.serializer.mixins import FunctionSerializerType
 from scaled.utility.zmq_config import ZMQConfig, ZMQType
-from scaled.protocol.python.message import MessageType, MessageVariant, Task, TaskResult, TaskStatus
+from scaled.protocol.python.message import (
+    FunctionRequest,
+    FunctionRequestType,
+    MessageType,
+    MessageVariant,
+    Task,
+    TaskResult,
+    TaskStatus,
+)
 from scaled.worker.agent.agent_thread import AgentThread
 from scaled.worker.memory_cleaner import MemoryCleaner
 
@@ -25,6 +36,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
         function_retention_seconds: int,
         garbage_collect_interval_seconds: int,
         trim_memory_threshold_bytes: int,
+        processing_queue_size: int,
         event_loop: str,
         serializer: FunctionSerializerType,
     ):
@@ -36,6 +48,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
         self._function_retention_seconds = function_retention_seconds
         self._garbage_collect_interval_seconds = garbage_collect_interval_seconds
         self._trim_memory_threshold_bytes = trim_memory_threshold_bytes
+        self._processing_queue_size = processing_queue_size
         self._event_loop = event_loop
         self._stop_event = stop_event
         self._serializer = serializer
@@ -62,6 +75,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
 
     def __initialize(self):
         self.__register_signal()
+        tblib.pickling_support.install()
 
         context = zmq.Context()
         internal_address = ZMQConfig(type=ZMQType.inproc, host="memory")
@@ -75,6 +89,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
             address=internal_address,
             callback=self.__on_connector_receive,
             daemonic=False,
+            receive_high_watermark=self._processing_queue_size,
         )
 
         self._agent = AgentThread(
@@ -83,6 +98,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
             internal_address=internal_address,
             heartbeat_interval_seconds=self._heartbeat_interval_seconds,
             function_retention_seconds=self._function_retention_seconds,
+            per_worker_processing_queue_size=self._processing_queue_size,
             event_loop=self._event_loop,
         )
         self._agent.start()
@@ -105,29 +121,50 @@ class Worker(multiprocessing.get_context("spawn").Process):
         signal.signal(signal.SIGINT, self.shutdown)
         signal.signal(signal.SIGTERM, self.shutdown)
 
-    def __on_connector_receive(self, message_type: MessageType, task: MessageVariant):
-        assert message_type == MessageType.Task
-        assert isinstance(task, Task)
+    def __on_connector_receive(self, message_type: MessageType, message: MessageVariant):
+        if message_type == MessageType.FunctionRequest:
+            self.__on_receive_function_request(message)
+            return
 
+        if message_type == MessageType.Task:
+            self.__on_received_task(message)
+            return
+
+        raise TypeError(f"unknown {message_type=}")
+
+    def __on_receive_function_request(self, request: FunctionRequest):
+        if request.type == FunctionRequestType.Add:
+            self._cached_functions[request.function_id] = self._serializer.deserialize_function(request.content)
+            return
+
+        if request.type == FunctionRequestType.Delete:
+            self._cached_functions.pop(request.function_id)
+            return
+
+        raise TypeError(f"unknown request {request=}")
+
+    def __on_received_task(self, task: Task):
         begin = time.monotonic()
         try:
-            if task.function_id not in self._cached_functions:
-                self._cached_functions[task.function_id] = self._serializer.deserialize_function(task.function_content)
-
             function = self._cached_functions[task.function_id]
             args, kwargs = self._serializer.deserialize_arguments(task.function_args)
 
             result = function(*args, **kwargs)
 
             result_bytes = self._serializer.serialize_result(result)
-            self._internal_connector.send(
+            self._internal_connector.send_immediately(
                 MessageType.TaskResult,
                 TaskResult(task.task_id, TaskStatus.Success, time.monotonic() - begin, result_bytes),
             )
 
         except Exception as e:
-            logging.exception(f"error when processing {task=}:")
-            self._internal_connector.send(
+            logging.exception(f"exception when processing task_id={task.task_id.hex()}:")
+            self._internal_connector.send_immediately(
                 MessageType.TaskResult,
-                TaskResult(task.task_id, TaskStatus.Failed, time.monotonic() - begin, str(e).encode()),
+                TaskResult(
+                    task.task_id,
+                    TaskStatus.Failed,
+                    time.monotonic() - begin,
+                    pickle.dumps(e, protocol=pickle.HIGHEST_PROTOCOL),
+                ),
             )
